@@ -14,8 +14,24 @@ function renderDiff(pathBefore, pathAfter, contentsBefore, contentsAfter) {
     afterName: pathAfter || '(none)',
     contextSize: 10
   };
-  var language = guessLanguage(pathBefore || pathAfter);
-  if (language && hljs.getLanguage(language)) {
+
+  // First guess a language based on the file name.
+  // Fall back to guessing based on the contents of the longer version.
+  var path = pathBefore || pathAfter;
+  var language = codediff.guessLanguageUsingFileName(path);
+
+  var lengthOrZero = function (data) {
+    return data ? data.length : 0;
+  };
+
+  if (!language && !_.contains(HIGHLIGHT_BLACKLIST, extractFilename(path))) {
+    var byLength = [contentsBefore, contentsAfter];
+    if (contentsAfter && lengthOrZero(contentsAfter) > lengthOrZero(contentsBefore)) {
+      byLength = [byLength[1], byLength[0]];
+    }
+    language = codediff.guessLanguageUsingContents(byLength[0]);
+  }
+  if (language) {
     opts.language = language;
   }
 
@@ -24,17 +40,17 @@ function renderDiff(pathBefore, pathAfter, contentsBefore, contentsAfter) {
   return diffDiv;
 }
 
-// Guess the language of code based on its file name.
-function guessLanguage(filename) {
-  var m = /\.([^.]+)$/.exec(filename);
-  if (m) {
-    var ext = m[1];
-    if (ext == 'py') return 'python';
-    return m[1];
-  } else {
-    return undefined;
-  }
+
+function extractFilename(path) {
+  var parts = path.split('/');
+  return parts[parts.length - 1];
 }
+var HIGHLIGHT_BLACKLIST = [
+  'TODO',
+  'README',
+  'NOTES'
+];
+
 
 // Useful for avoiding capturing keyboard shortcuts and text entry.
 function isLegitKeypress(e) {
